#encoding: UTF-8 
=begin
/***************************************************************************
 *   ©2019-2019 Michael Uplawski <michael.uplawski@uplawski.eu>            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
=end


require 'optparse'
require 'optparse/time'
require 'ostruct'

class ArgParser 

	# Returns a structure describing the options.
	#
	def self.parse(args)
		# The options specified on the command line will be collected in <b>options</b>.
		# We set default values here.
		options = OpenStruct.new
		options.date = true 
                options.format = "%d.%m.%Y" 
		options.number = false 
                options.s_value = 0
                options.e_value = 0
                options.n_width = 0
                options.file = nil
                options.templates = nil
                # options.style = nil
                options.cols = 1
                options.weeks = false
                options.highlight = false
                options.weekend = true

                op = OptionParser.new do |opts|
                  opts.banner = "Usage:\t" << "%s <options>" %($0) <<"\n"

                  opts.separator ""
                  opts.separator "Specific options:"

                  opts.on('-' << "w", '--' << "weeks", "Delimit weeks") do 
                    options.weeks = true
                  end

                  opts.on('--' << "highlight", "highlight week-ends") do 
                    options.highlight = true
                  end

                  opts.on('--' << "no-we", "Ignore week-ends") do 
                    options.weekend = false
                  end

                  opts.on('-' << "bVALUE", '--' << "begin=VALUE", "Begin value") do |value|
                    options.s_value = value
                  end

                  opts.on('-' << "cNUM", '--' << "cols=NUM", "Number of columns") do |cols|
                    options.cols = cols.to_i
                  end

                  opts.on('-' << "eVALUE", '--' << "end=VALUE", "End value") do |value|
                    options.e_value = value
                  end

                  opts.on('-' << "tTEMPLATES", '--' << "templates=TEMPLATE", "Directory of templates") do |templates|
                    options.templates = File.absolute_path(templates)
                  end

                  opts.on('-' << 'dFORMAT', '--' << "date=FORMAT", "Generate date-cells (default)") do |format|
                    options.date = true
                    options.format=format
                    options.number = false
                    options.n_width = 0
                  end

                  opts.on('-' << 'nWIDTH', '--' << "number=WIDTH", "Generate number-cells") do |width|
                    options.number = true
                    options.date = false
                    options.format = nil
                    options.n_width = width
                  end

                  opts.on('-' << 'fFILE', '--' << "file=FILE", "Write output to file FILE") do |file|
                    options.file = File.absolute_path(file)
                  end

                  opts.separator ""
                  opts.separator ("Common options") << ':'

                  # No argument, shows at tail.  This will print an options summary.
                  opts.on_tail(("-h"), ("--help"), ("Show this message") ) do
                    puts opts
                    exit true
                  end

                  opts.on_tail(("-v"), ("--version"), ("Show version and program information") ) do
                    puts "\t#{$0}"
                    puts "\t© 2018-2019 Michael Uplawski <michael.uplawski at uplawski.eu>"
                    exit true
                  end
                end

                op.parse!(args)
                options
        end  # parse()

end  

